#
# spec file for package libtpms
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname libtpms0
Name:           libtpms
Version:        0.8.2
Release:        1.1
Summary:        Library providing Trusted Platform Module (TPM) functionality
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/stefanberger/libtpms
Source0:        https://github.com/stefanberger/libtpms/archive/v%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  mozilla-nspr-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig

%description
A library providing TPM functionality for VMs. Targeted for integration
into Qemu.

%package -n %{lname}
Summary:        Library providing Trusted Platform Module (TPM) functionality
Group:          Development/Libraries/C and C++

%description -n %{lname}
A library providing TPM functionality for VMs. Targeted for integration
into Qemu.

%package        devel
Summary:        Include files for libtpms
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       libopenssl-devel
Requires:       mozilla-nspr-devel

%description   devel
Libtpms header files and documentation.

%prep
%setup -q -n libtpms-%{version}

%build
./bootstrap.sh
%configure \
	--with-tpm2 \
	--with-openssl	\
        --disable-static

make %{?_smp_mflags}

%check
make %{?_smp_mflags} check

%install
install -d -m 0755 %{buildroot}%{_libdir}
install -d -m 0755 %{buildroot}%{_includedir}/libtpms
install -d -m 0755 %{buildroot}%{_mandir}/man3

%make_install

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%doc README CHANGES
%license LICENSE
%{_libdir}/%{name}.so.%{version}
%{_libdir}/%{name}.so.0

%files devel
%{_libdir}/%{name}.so
%{_libdir}/%{name}.la
%dir %{_includedir}/%{name}
%attr(644, root, root) %{_libdir}/pkgconfig/*.pc
%attr(644, root, root) %{_includedir}/%{name}/*.h
%attr(644, root, root) %{_mandir}/man3/*

%changelog
* Mon Apr 19 2021 glin@suse.com
- Update to version 0.8.2
  * NOTE: Downgrade to 0.7.x or below is not possible.
    Due to fixes in the TPM 2 prime number generation code in
    rev155 it is not possible to downgrade from libtpms version
    0.8.0 to some previous version. The seeds are now associated
    with an age so that older seeds use the old TPM 2 prime number
    generation code while newer seed use the newer code.
  * tpm2: rev155: Add new RsaAdjustPrimeCandidate code but do
    not use (bsc#1184939 CVE-2021-3505)
  * tpm2: Activate SEED_COMPAT_LEVEL_RSA_PRIME_ADJUST_FIX
    (bsc#1184939 CVE-2021-3505)
  * Update to TPM 2 code release 159
  - X509 support is enabled
    + SM2 signing of ceritificates is NOT supported
  - Authenticated timers are disabled
  * Update to TPM 2 code relase 162
  - ECC encryption / decryption is disabled
  * Fix support for elliptic curve due to missing unmarshalling
    code
  * Runtime filter supported elliptic curves supported by OpenSSL
  * Fix output buffer parameter and size for RSA decryption that
    could cause stack corruption under certain circumstances
  * Set the RSA PSS salt length to the digest length rather than
    max
  * Fixes to symmetric decryption related to input size check,
    defer padding to the user [EVP_CIPHER_CTX_set_padding(ctx, 0)]
    and to always use a temporary malloc'ed buffer for decryption
  * Fixed the set of PCRs belonging to the TCB group. This affects
    the pcrUpdateCounter in TPM2_Pcrread() responses, thus needs
    latest swtpm for test cases to succeed there.
* Fri Mar 19 2021 glin@suse.com
- Update to version 0.7.7
  * CryptSym: fix AES output IV (bsc#1183729, CVE-2021-3446)
  * tpm2: Fix public key context save due to ANY_OBJECT_Marshal usage
  * tpm2: Address some Coverity issues (false positives)
  * tpm1.2: Backported ASAN/UBSAN related fixes
  * tpm2: Return properly sized array for b parameter for NIST P521
    (HLK)
  * tpm2: Addressed issues detected by UBSAN
  * tpm2: Addressed issues detected by cppcheck (false positives)
* Mon Nov 23 2020 glin@suse.com
- Update to version 0.7.4
  * Addressed potential constant-time related issues in TPM 1.2 and
    TPM 2 code
    TPM 1.2: RSA decryption
    TPM 2: EcSchnorr and EcSM2 signatures; Ecsda is handled by OpenSSL
  * Fixed some compilation issues
* Thu Jul 23 2020 kai.liu@suse.com
- Update to version 0.7.3
  * Fixed the set of PCRs belonging to the TCB group. This affects
    the pcrUpdateCounter in TPM2_Pcrread() responses, thus needs
    latest `swtpm` (master, stable branches) for test cases to
    succeed there.
- Changes since version 0.7.2
  * Fix output buffer parameter and size for RSA decryption that
    could cause stack corruption under certain circumstances
  * Set the RSA PSS salt length to the digest length rathern than
    max. possible
  * Fixes to symmetric decrytion related to input size check, defer
    padding to the user [EVP_CIPHER_CTX_set_padding(ctx, 0)] and to
    always use a temporary malloc'ed buffer for decryption
- Changes since version 0.7.1
  * tpm2: Fix TDES key creation by adding missing un-/marshalling
    functions
  * tpm2: Fix a bug in CheckAuthSession
  * compilation fixes for TPM 1.2 & TPM 2 and various architectures
    and gcc versions
  * Fix support for NIST curves P{192,224,521} and SM2 P256 and
    BNP648 that would not work;
  * Runtime filter elliptic curves (that OpenSSL does not support)
    and do not advertise those curves as capabilities
  * Removed unnecessary space in MANUFACTURER "IBM " -> "IBM"
* Thu Sep  5 2019 glin@suse.com
- Update to version 0.7.0
  * fixes for TPM2
- Add gcc-c++ to BuildRequires
* Mon Jan 28 2019 glin@suse.com
- Update to version 0.6.0
  * Introduce TPM2 support
- Use %%license tag for LICENSE
* Wed Jan 17 2018 vcizek@suse.com
- Update to version 0.6.0-dev1
  * no upstream changelog
  * fix build with openssl 1.1 (bsc#1074801)
- fix rpm group
* Sat Mar 21 2015 p.drouand@gmail.com
- Update to version 0.5.2
  * No entry for this release
- Update project home and download Urls
- Add autoconf, automake and libtool build require; the tarball
  comes from git and configure script has to be generated
* Tue Jan 14 2014 meissner@suse.com
- import 0.5.1
  - software TPM driver library for hooking into QEMU
